# SPDX-License-Identifier: Apache-2.0

from flask import Blueprint, make_response
from sqlalchemy import select
from sqlalchemy.orm import Session

from foxfiles.files import get_file_by_hash
from foxfiles.db import engine, File

bp = Blueprint("files", __name__)


@bp.get("/<file_id>.<extension>")
def get_file_id(file_id: str, extension: str):
    """Gets a file by its short ID."""
    return _get_file(select(File).where(File.url_id == file_id))


@bp.get("/<hash>/<filename>")
def get_file_by_hash_name(hash: str, filename: str):
    """Gets a file by its hash and filename."""
    return _get_file(
        select(File).where(File.hash == hash).where(File.filename == filename)
    )


def _get_file(stmt):
    with Session(engine) as session:
        file = session.scalar(stmt)
        if file is None:
            return "File not found", 404

        data = get_file_by_hash(file.hash, file.content_type)
        resp = make_response(data)
        resp.status = 200
        resp.content_type = file.content_type
        resp.content_length = len(data)

        return resp
